@@ -1,6 +1,4 @@
-
-/*    $OpenBSD: getopt_long.c,v 1.17 2004/06/03 18:46:52 millert Exp $    */
-/*    $NetBSD: getopt_long.c,v 1.15 2002/01/31 22:43:40 tv Exp $    */
+/*      $OpenBSD: getopt_long.c,v 1.20 2005/10/25 15:49:37 jmc Exp $    */
 
 /*
  * Copyright (c) 2002 Todd C. Miller <Todd.Miller@courtesan.com>
@@ -32,13 +30,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *        This product includes software developed by the NetBSD
- *        Foundation, Inc. and its contributors.
- * 4. Neither the name of The NetBSD Foundation nor the names of its
- *    contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -76,11 +67,11 @@ const char    *pure_optarg;        /* argument associated with option */
 
 # define FLAG_PERMUTE    0x01    /* permute non-options to the end of argv */
 # define FLAG_ALLARGS    0x02    /* treat non-options as args to option "-1" */
-# define FLAG_LONGONLY    0x04    /* operate as pure_pure_getopt_long_only */
+# define FLAG_LONGONLY   0x04    /* operate as pure_getopt_long_only */
 
 /* return values */
-# define    BADCH        (int)'?'
-# define    BADARG        ((*options == ':') ? (int)':' : (int)'?')
+# define    BADCH       (int)'?'
+# define    BADARG      ((*options == ':') ? (int)':' : (int)'?')
 # define    INORDER     (int)1
 
 # define    EMSG        ""
@@ -99,12 +90,12 @@ static int nonopt_start = -1; /* first non option argument (for permute) */
 static int nonopt_end = -1;   /* first option after non options (for permute) */
 
 /* Error messages */
-static const char *recargchar = "option requires an argument -- %c";
-static const char *recargstring = "option requires an argument -- %s";
-static const char *ambig = "ambiguous option -- %.*s";
-static const char *noarg = "option doesn't take an argument -- %.*s";
-static const char *illoptchar = "unknown option -- %c";
-static const char *illoptstring = "unknown option -- %s";
+static const char *recargchar = "option requires an argument -- %c\n";
+static const char *recargstring = "option requires an argument -- %s\n";
+static const char *ambig = "ambiguous option -- %.*s\n";
+static const char *noarg = "option doesn't take an argument -- %.*s\n";
+static const char *illoptchar = "unknown option -- %c\n";
+static const char *illoptstring = "unknown option -- %s\n";
 
 /*
  * Compute the greatest common divisor of a and b.
@@ -371,11 +362,14 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
         }
         if (nonopt_start != -1 && nonopt_end == -1)
             nonopt_end = pure_optind;
-        
-        /* If we have "-" do nothing, if "--" we are done. */
-        
+
+        /*
+         * Check for "--" or "--foo" with no long options
+         * but if pure_place is simply "-" leave it unmolested.
+         */
+
         if (pure_place[1] != '\0' && *++pure_place == '-' &&
-            pure_place[1] == '\0') {
+            (pure_place[1] == '\0' || long_options == NULL)) {
             pure_optind++;
             pure_place = EMSG;
             /*
@@ -396,7 +390,7 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
      * Check long options if:
      *  1) we were passed some
      *  2) the arg is not just "-"
-     *  3) either the arg starts with -- we are pure_pure_getopt_long_only()
+     *  3) either the arg starts with -- we are pure_getopt_long_only()
      */
     if (long_options != NULL && pure_place != nargv[pure_optind] &&
         (*pure_place == '-' || (flags & FLAG_LONGONLY))) {
@@ -414,15 +408,16 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
         }
     }
     
-    if ((optchar = (int)*pure_place++) == (int)':' ||
-        (oli = strchr(options, optchar)) == NULL) {
-        /*
-         * If the user specified "-" and '-' isn't listed in
-         * options, return -1 (non-option) as per POSIX.
-         * Otherwise, it is an unknown option character (or :').
-         */
-        if (optchar == (int) '-' && *pure_place == '\0')
+    if ((optchar = (int) *pure_place++) == ':' ||
+        (optchar == '-' && *pure_place) != '\0' ||
+        (oli = strchr(options, optchar)) == NULL) { 
+         /*
+          * If the user didn't specify '-' as an option,
+          * assume it means -1 as POSIX specifies.
+          */
+        if (optchar == '-')
             return -1;
+        /* option letter unknown or ':' */
         if (!*pure_place)
             ++pure_optind;
         if (PRINT_ERROR)
@@ -448,30 +443,22 @@ static int pure_getopt_internal(int nargc, char * const *nargv,
         return optchar;
     }
     if (*++oli != ':') {            /* doesn't take argument */
-        if (!*pure_place)
+        if (!*pure_place) {
             ++pure_optind;
+        }
     } else {                /* takes (optional) argument */
         pure_optarg = NULL;
-        if (*pure_place)            /* no white space */
+        if (*pure_place) {            /* no white space */
             pure_optarg = pure_place;
-        /* XXX: disable test for :: if PC? (GNU doesn't) */
-        else if (oli[1] != ':') {    /* arg not optional */
+        } else if (oli[1] != ':') {    /* arg not optional */
             if (++pure_optind >= nargc) {    /* no arg */
                 pure_place = EMSG;
                 if (PRINT_ERROR)
                     fprintf(stderr, recargchar, optchar);
                 pure_optopt = optchar;
                 return BADARG;
-            } else if (!(flags & FLAG_PERMUTE)) {
-                /* 
-                 * If permutation is disabled, we can accept an
-                 * optional arg separated by whitespace so long
-                 * as it does not start with a dash (-).
-                 */
-                 if (pure_optind + 1 < nargc && pure_optind + 1 > 0 &&
-                     *nargv[pure_optind + 1] != '-') {
-                     pure_optarg = nargv[++pure_optind];
-                 }
+            } else {
+                pure_optarg = nargv[pure_optind];
             }
         }
         pure_place = EMSG;
@@ -489,7 +476,7 @@ int pure_getopt(int nargc, char * const *nargv, const char *options)
 {
     
     /*
-     * We dont' pass FLAG_PERMUTE to pure_getopt_internal() since
+     * We don't pass FLAG_PERMUTE to pure_getopt_internal() since
      * the BSD getopt(3) (unlike GNU) has never done this.
      *
      * Furthermore, since many privileged programs call getopt()
@@ -511,10 +498,10 @@ int pure_getopt_long(int nargc, char * const *nargv, const char *options,
 }
 
 /*
- * pure_pure_getopt_long_only --
+ * pure_getopt_long_only --
  *    Parse argc/argv argument vector.
  */
-int pure_pure_getopt_long_only(int nargc, char * const *nargv,
+int pure_getopt_long_only(int nargc, char * const *nargv,
                                const char *options,
                                const struct pure_option *long_options,
                                int *idx)
