@@ -152,8 +152,8 @@ int sfgets(void)
 #else
 static char *revealextraspc(char * const s_)
 {
-    register unsigned char *s = (unsigned char *) s_;
-    register unsigned char *sn;
+    unsigned char *s = (unsigned char *) s_;
+    unsigned char *sn;
     
     if (s == NULL) {
         return s_;
@@ -223,6 +223,10 @@ void parser(void)
 #endif
     size_t n;
 
+#ifdef IMPLICIT_TLS
+    (void) tls_init_new_session();
+    data_protection_level = CPL_PRIVATE;
+#endif
     for (;;) {
         xferfd = -1;
         if (state_needs_update != 0) {
@@ -311,7 +315,7 @@ void parser(void)
          */
         
 #ifndef MINIMAL
-        if (!strcmp(cmd, "noop") || !strcmp(cmd, "allo")) {
+        if (!strcmp(cmd, "noop")) {
             antiidle();
             donoop();
             goto wayout;
@@ -431,12 +435,12 @@ void parser(void)
 #ifndef MINIMAL
             } else if (!strcmp(cmd, "eprt")) {
                 doeprt(arg);
-        } else if (!strcmp(cmd, "esta") &&
-                   disallow_passive == 0 &&
-                   STORAGE_FAMILY(force_passive_ip) == 0) {
-            doesta();
-        } else if (!strcmp(cmd, "estp")) {
-            doestp();
+            } else if (!strcmp(cmd, "esta") &&
+                       disallow_passive == 0 &&
+                       STORAGE_FAMILY(force_passive_ip) == 0) {
+                doesta();
+            } else if (!strcmp(cmd, "estp")) {
+                doestp();
 #endif
             } else if (disallow_passive == 0 && 
                        (!strcmp(cmd, "pasv") || !strcmp(cmd, "p@sw"))) {
@@ -456,6 +460,13 @@ void parser(void)
 #ifndef MINIMAL            
             } else if (disallow_passive == 0 && !strcmp(cmd, "spsv")) {
                 dopasv(2);
+            } else if (!strcmp(cmd, "allo")) {
+                if (*arg == 0) {
+                    addreply_noformat(501, MSG_STAT_FAILURE);
+                } else {
+                    const off_t size = (off_t) strtoull(arg, NULL, 10);
+                    doallo(size);
+                }
 #endif
             } else if (!strcmp(cmd, "pwd") || !strcmp(cmd, "xpwd")) {
 #ifdef WITH_RFC2640
@@ -562,15 +573,8 @@ void parser(void)
 #ifndef MINIMAL
             } else if (!strcmp(cmd, "stat")) {
                 if (*arg != 0) {
-# ifdef WITH_TLS
-                    if (tls_cnx != NULL) {
-                        addreply_noformat(500, MSG_UNKNOWN_COMMAND);
-                    } else
-# endif
-                    {
-                        modern_listings = 0;
-                        donlist(arg, 1, 1, 1);
-                    }
+                    modern_listings = 0;
+                    donlist(arg, 1, 1, 1, 1);
                 } else {
                     addreply_noformat(211, "http://www.pureftpd.org/");
                 }
@@ -586,7 +590,7 @@ void parser(void)
                 } else
 #endif
                 {
-                    donlist(arg, 0, 1, 1);
+                    donlist(arg, 0, 1, 0, 1);
                 }
             } else if (!strcmp(cmd, "nlst")) {
 #ifndef MINIMAL                
@@ -599,7 +603,7 @@ void parser(void)
                 } else
 #endif
                 {
-                    donlist(arg, 0, 0, broken_client_compat);
+                    donlist(arg, 0, 0, 0, broken_client_compat);
                 }
 #ifndef MINIMAL
             } else if (!strcmp(cmd, "mlst")) {
@@ -621,7 +625,7 @@ void parser(void)
                 } else
 #endif
                 {
-                    donlist(arg, 0, 1, 0);
+                    donlist(arg, 0, 1, 1, 0);
                 }
 #endif
             } else if (!strcmp(cmd, "abor")) {
@@ -690,7 +694,7 @@ void parser(void)
                         goto chmod_wayout;
                     }
                     dochmod(sitearg2, mode);
-                  chmod_wayout:
+                    chmod_wayout:
                     (void) 0;
                 } else if (!strcasecmp(arg, "utime")) {
                     char *sitearg2;
@@ -700,44 +704,44 @@ void parser(void)
                         goto utime_wayout;
                     }		    
                     if ((sitearg2 = strrchr(sitearg, ' ')) == NULL ||
-			sitearg2 == sitearg) {
+                        sitearg2 == sitearg) {
                         addreply_noformat(501, MSG_MISSING_ARG);
                         goto utime_wayout;
-		    }
-		    if (strcasecmp(sitearg2, " UTC") != 0) {
+                    }
+                    if (strcasecmp(sitearg2, " UTC") != 0) {
                         addreply_noformat(500, "UTC Only");
                         goto utime_wayout;			
-		    }
-		    *sitearg2-- = 0;
+                    }
+                    *sitearg2-- = 0;
                     if ((sitearg2 = strrchr(sitearg, ' ')) == NULL ||
-			sitearg2 == sitearg) {
-			utime_no_arg:
+                        sitearg2 == sitearg) {
+                        utime_no_arg:
                         addreply_noformat(501, MSG_MISSING_ARG);
                         goto utime_wayout;
-		    }
-		    *sitearg2-- = 0;
+                    }
+                    *sitearg2-- = 0;
                     if ((sitearg2 = strrchr(sitearg, ' ')) == NULL ||
-			sitearg2 == sitearg) {
-			goto utime_no_arg;
-		    }
-		    *sitearg2-- = 0;
-                    if ((sitearg2 = strrchr(sitearg, ' ')) == NULL ||
-			sitearg2 == sitearg) {
+                        sitearg2 == sitearg) {
                         goto utime_no_arg;
-		    }
-		    *sitearg2++ = 0;
-		    if (*sitearg2 == 0) {
+                    }
+                    *sitearg2-- = 0;
+                    if ((sitearg2 = strrchr(sitearg, ' ')) == NULL ||
+                        sitearg2 == sitearg) {
+                        goto utime_no_arg;
+                    }
+                    *sitearg2++ = 0;
+                    if (*sitearg2 == 0) {
                         goto utime_no_arg;			
-		    }
+                    }
                     doutime(sitearg, sitearg2);
-                  utime_wayout:
+                    utime_wayout:
                     (void) 0;
 # ifdef WITH_DIRALIASES		    
                 } else if (!strcasecmp(arg, "alias")) {
                     if (sitearg == NULL || *sitearg == 0) {
                         print_aliases();
                     } else {
-                        register const char *alias;
+                        const char *alias;
                         
                         if ((alias = lookup_alias(sitearg)) != NULL) {
                             addreply(214, MSG_ALIASES_ALIAS, sitearg, alias);
@@ -779,10 +783,10 @@ void parser(void)
             }
         }
         noopidle = (time_t) -1;
-	wayout:
+        wayout:
 #ifdef WITH_RFC2640
-	free(narg);
-	narg = NULL;
+        free(narg);
+        narg = NULL;
 #endif
 #ifdef THROTTLING
         if (throttling_delay != 0UL) {
