@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Chybn kvota"
 #define MSG_QUOTA_FILES "%llu soubor pouitch (%d%%) - autorizovanch: %llu soubor"
 #define MSG_QUOTA_SIZE "%llu kilobajt pouitch (%d%%) - autorizovanch: %llu kilobajt"
-#define MSG_QUOTA_EXCEEDED "Kvota pekroena: %s nebude uloen"
+#define MSG_QUOTA_EXCEEDED "Kvota pekroena: [%s] nebude uloen"
 #define MSG_AUTH_UNKNOWN "Neznm autentifikan metoda"
 #define MSG_PDB_BROKEN "Nebylo mon pest indexovan soubor puredb (nebo byla detekovna star verze) - Vyzkouejte spustit pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s je alias pro %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
