@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Quota ungltig."
 #define MSG_QUOTA_FILES "%llu Dateien benutzt (%d%%) - erlaubt: %llu Dateien."
 #define MSG_QUOTA_SIZE "%llu Kilobyte benutzt (%d%%) - erlaubt: %llu Kb."
-#define MSG_QUOTA_EXCEEDED "Quota berschritten: %s wird nicht gespeichert."
+#define MSG_QUOTA_EXCEEDED "Quota berschritten: [%s] wird nicht gespeichert."
 #define MSG_AUTH_UNKNOWN "Unbekannte Authentifizierungsmethode."
 #define MSG_PDB_BROKEN "Konnte indizierte puredb-Datei nicht lesen (oder altes Format gefunden) - Versuche pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s ist ein Alias fr %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
