@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Cuota invlida"
 #define MSG_QUOTA_FILES "%llu archivos utilizados (%d%%) - autorizados: %llu archivos"
 #define MSG_QUOTA_SIZE "%llu Kbytes utilizados (%d%%) - autorizados: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Cuota excedida : %s no ser guardado"
+#define MSG_QUOTA_EXCEEDED "Cuota excedida : [%s] no ser guardado"
 #define MSG_AUTH_UNKNOWN "Mtodo de autentificacin desconocido"
 #define MSG_PDB_BROKEN "No se puede leer el fichero indexado puredb (o formato antiguo detectado) - Prueba a ejecutar pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s es un alias para %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
