@@ -12,7 +12,7 @@
 #define MSG_TIMEOUT_PARSER "Temps de reponse depasse - Tapez un peu plus vite la prochaine fois"
 #define MSG_LINE_TOO_LONG "Ligne trop longue"
 #define MSG_LOG_OVERFLOW "Le client a tente d'effectuer un depassement de capacite"
-#define MSG_GOODBYE "Au revoir. Vous avez uploade %llu et downloade %llu Koctets."
+#define MSG_GOODBYE "Au revoir. Vous avez uploade %llu et downloade %llu Ko."
 #define MSG_DEBUG_COMMAND "Commande"
 #define MSG_IS_YOUR_CURRENT_LOCATION "est votre position actuelle"
 #define MSG_NOT_LOGGED_IN "Vous n'etes pas connecte"
@@ -109,17 +109,17 @@
     "Veuillez uploader quelque chose avant de downloader autre chose."
 #define MSG_NO_MORE_TO_DOWNLOAD "Plus rien a downloader"
 #define MSG_WINNER "Cet ordinateur est votre ami. Faites lui confiance"
-#define MSG_KBYTES_LEFT "%.1f Koctets a downloader"
+#define MSG_KBYTES_LEFT "%.1f Ko a downloader"
 #define MSG_ABORTED "Transfert interrompu"
 #define MSG_DATA_WRITE_FAILED "Erreur d'ecriture dans la connexion de donnees"
 #define MSG_DATA_READ_FAILED "Erreur de lecture dans la connexion de donnees"
 #define MSG_MMAP_FAILED "Ne peut mapper le fichier dans la memoire"
 #define MSG_WRITE_FAILED "Erreur lors de l'ecriture dans le fichier"
-#define MSG_TRANSFER_RATE_M "%.3f secondes (mesuree ici), %.2f Moctets par seconde"
-#define MSG_TRANSFER_RATE_K "%.3f secondes (mesuree ici), %.2f Koctets par seconde"
-#define MSG_TRANSFER_RATE_B "%.3f secondes (mesuree ici), %.2f octets par seconde"
-#define MSG_SPACE_FREE_M "%.1f Moctets d'espace disque libre"
-#define MSG_SPACE_FREE_K "%f Koctets d'espace disque libre"
+#define MSG_TRANSFER_RATE_M "%.3f secondes (mesurees ici), %.2f Mo par seconde"
+#define MSG_TRANSFER_RATE_K "%.3f secondes (mesurees ici), %.2f Ko par seconde"
+#define MSG_TRANSFER_RATE_B "%.3f secondes (mesurees ici), %.2f octets par seconde"
+#define MSG_SPACE_FREE_M "%.1f Mo d'espace disque libre"
+#define MSG_SPACE_FREE_K "%f Ko d'espace disque libre"
 #define MSG_DOWNLOADED "downloade"
 #define MSG_REST_NOT_NUMERIC "REST necessite un parametre numerique"
 #define MSG_REST_ASCII_STRICT "Le marqueur de reponse doit etre 0 en mode ASCII"
@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Quota invalide"
 #define MSG_QUOTA_FILES "%llu fichiers utilises (%d%%) - autorises : %llu fichiers"
 #define MSG_QUOTA_SIZE "%llu Ko utilises (%d%%) - autorises : %llu Ko"
-#define MSG_QUOTA_EXCEEDED "Quota depasse : %s ne sera pas sauvegarde"
+#define MSG_QUOTA_EXCEEDED "Quota depasse : [%s] ne sera pas sauvegarde"
 #define MSG_AUTH_UNKNOWN "Methode d'authentification inconnue"
 #define MSG_PDB_BROKEN "Impossible de lire le fichier puredb indexe (ou il est dans un vieux format) - Essayez pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s est un raccourci pour %s."
@@ -219,8 +219,10 @@
 #define MSG_TLS_NEEDED "Desole, les sessions en clair ne sont pas acceptees sur ce serveur.\n" \
     "Veuillez vous reconnecter en utilisant les mechanismes de securite SSL/TLS."
 #define MSG_ILLEGAL_CHARSET "Jeu de caracteres illegal"
-#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
-#define MSG_PROT_OK "Data protection level set to \"%s\""
-#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
-#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
-#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_TLS_NO_CTX "SSL/TLS: context non trouve. Deconnexion."
+#define MSG_PROT_OK "Niveau de protection regle a \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "La connexion pour les donnees ne peut etre cree avec ce niveau de protection (PROT)."
+#define MSG_PROT_UNKNOWN_LEVEL "Niveau de protection %s non pris en charge. Utilisation de \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT doit etre precede d'une commande PBSZ reussie"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP n'a pas retourne d'attribut userPassword, verifiez les droits d'acces LDAP."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Methode LDAPAuthMethod invalide dans le fichier de configuration. Ce doit etre 'bind' ou 'password'."
