@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "rvnytelen kvta"
 #define MSG_QUOTA_FILES "%llu fjl hasznlt (%d%%) - engedlyezve: %llu fjl"
 #define MSG_QUOTA_SIZE "%llu Kbjt hasznlt (%d%%) - engedlyezve: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Kvta elrve: %s ments sikertelen"
+#define MSG_QUOTA_EXCEEDED "Kvta elrve: [%s] ments sikertelen"
 #define MSG_AUTH_UNKNOWN "Ismeretlen hitelestsi mdszer"
 #define MSG_PDB_BROKEN "Az indexelt puredb fjl olvassa sikertelen (vagy rgi formtum) - prblja: pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s egy alias %s -nak."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
