@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Ugyldig quota"
 #define MSG_QUOTA_FILES "%llu filer blir brukt (%d%%) - tillatt: %llu filer"
 #define MSG_QUOTA_SIZE "%llu Kbytes blir brukt (%d%%) - tillatt: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Quota oversteget: %s blir ikke lagret"
+#define MSG_QUOTA_EXCEEDED "Quota oversteget: [%s] blir ikke lagret"
 #define MSG_AUTH_UNKNOWN "Ukjent godkjennelsesmetode"
 #define MSG_PDB_BROKEN "Kan ikke lese den indekserte puredb-filen (eller den er i gammelt format) - Prv pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s er et alias for %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
