@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Nieprawidowa quota"
 #define MSG_QUOTA_FILES "%llu plikw uytych (%d%%) - autoryzowano: %llu plikw"
 #define MSG_QUOTA_SIZE "%llu Kbajtw uytych (%d%%) - autoryzowano: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Przekroczona quota: %s nie zostanie zapisany"
+#define MSG_QUOTA_EXCEEDED "Przekroczona quota: [%s] nie zostanie zapisany"
 #define MSG_AUTH_UNKNOWN "Nieznana metoda autentyfikacji"
 #define MSG_PDB_BROKEN "Nie udao si odczyta indeksowanego pliku puredb (lub wykryto stary format) - Sprbuj uruchomi pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s is an alias for %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
