@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Cota invlida"
 #define MSG_QUOTA_FILES "%llu arquivos usados (%d%%) - autorizado: %llu arquivos"
 #define MSG_QUOTA_SIZE "%llu Kbytes usados (%d%%) - autorizado: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Cota excedida : %s no ser armazenado"
+#define MSG_QUOTA_EXCEEDED "Cota excedida : [%s] no ser armazenado"
 #define MSG_AUTH_UNKNOWN "Mtodo de autenticao desconhecido"
 #define MSG_PDB_BROKEN "No foi possvel ler o arquivo indexado do puredb (ou um formato antigo foi detectado) - Experimente pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s  um apelido para %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
