@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Chybna kvota"
 #define MSG_QUOTA_FILES "%llu suborov pouzitych (%d%%) - autorizovanych: %llu suborov"
 #define MSG_QUOTA_SIZE "%llu kilobajtov pouzitych (%d%%) - autorizovanych: %llu kilobajtov"
-#define MSG_QUOTA_EXCEEDED "Kvota prekrocena : %s nebude ulozeny"
+#define MSG_QUOTA_EXCEEDED "Kvota prekrocena : [%s] nebude ulozeny"
 #define MSG_AUTH_UNKNOWN "Neznama autentifikacna metoda"
 #define MSG_PDB_BROKEN "Nebolo mozne precitat indexovany subor puredb (alebo bola detekovana stara verzia) - Vyskusajte spustit pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s je aliasom pre %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
