@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Ogiltig kvot"
 #define MSG_QUOTA_FILES "%llu filer anvnda (%d%%) - authorized: %llu files"
 #define MSG_QUOTA_SIZE "%llu Kbytes anvnda (%d%%) - Tilltet: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Kvoten verskriden: %s kommer inte att sparas"
+#define MSG_QUOTA_EXCEEDED "Kvoten verskriden: [%s] kommer inte att sparas"
 #define MSG_AUTH_UNKNOWN "Oknd behrighetskontroll"
 #define MSG_PDB_BROKEN "Kan ej lsa den indexerade puredb filen (eller gammalt format) - Frsk med pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s r ett alias fr %s."
@@ -224,3 +224,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
