@@ -22,25 +22,33 @@ int hasquota(void)
     return 0;
 }
 
-int quota_update(Quota * const quota,
+int quota_update(Quota *quota,
                  const long long files_add,
                  const long long size_add,
                  int *overflow)
 {
     int fd;
     Quota old_quota = { 0ULL, 0ULL };
+    Quota dummy_quota;
     struct flock lock;
     ssize_t readen;
     int err = -1;
     char buf[84];  
-    char *bufpnt = buf;    
+    char *bufpnt = buf;
+    int dummy_overflow;
     ssize_t left = (ssize_t) (sizeof buf - 1U);
     
-    *overflow = 0;
-    *quota = old_quota;
     if (hasquota() != 0 || chrooted == 0) {
         return -2;
     }    
+    if (overflow == NULL) {
+        overflow = &dummy_overflow;
+    }
+    if (quota == NULL) {
+        quota = &dummy_quota;
+    }
+    *overflow = 0;
+    *quota = old_quota;
     if ((fd = open("/" QUOTA_FILE, O_RDWR | O_CREAT | O_NOFOLLOW, 
                    (mode_t) 0600)) == -1) {
         return -1;
@@ -81,12 +89,9 @@ int quota_update(Quota * const quota,
         } else {
             quota->files = 0ULL;
         }
-    } else if (files_add > 0LL) {
-        if ((user_quota_files > quota->files) && 
-            (user_quota_files - quota->files >=
-             (unsigned long long) files_add)) {
-            quota->files += files_add;
-        } else {
+    } else if (files_add >= 0LL) {
+        quota->files += (unsigned long long) files_add;
+        if (quota->files > user_quota_files) {
             *overflow = 1;
         }
     }
@@ -96,19 +101,12 @@ int quota_update(Quota * const quota,
         } else {
             quota->size = 0ULL;
         }
-    } else if (size_add > 0LL) {
-        if ((user_quota_size > quota->size) &&
-            (user_quota_size - quota->size >= 
-             (unsigned long long) size_add)) {
-            quota->size += size_add;
-        } else {
+    } else if (size_add >= 0LL) {
+        quota->size += size_add;
+        if (quota->size > user_quota_size) {
             *overflow = 2;
         }
     }
-    if (*overflow != 0) {
-        *quota = old_quota;
-        goto okbye;
-    }
     if ((old_quota.size != quota->size || old_quota.files != quota->files) &&
         !SNCHECK(snprintf(buf, sizeof buf, "%llu %llu\n",
                           quota->files, quota->size), sizeof buf) &&
@@ -136,13 +134,12 @@ void displayquota(Quota * const quota_)
 {
     Quota quota;
     double pct;
-    int overflow;
     
     if (hasquota() != 0) {
         return;
     }
     if (quota_ == NULL) {
-        if (quota_update(&quota, 0LL, 0LL, &overflow) != 0) {
+        if (quota_update(&quota, 0LL, 0LL, NULL) != 0) {
             return;
         }
     } else {
