@@ -10,7 +10,7 @@
 int tls_init_library(void);
 void tls_free_library(void);
 int tls_init_new_session(void);
-int tls_init_data_session(int fd);
+int tls_init_data_session(const int fd, const int passive);
 void tls_close_session(SSL **cnx);
 
 # ifndef IN_TLS_C
@@ -28,10 +28,6 @@ extern
 # endif
     SSL *tls_data_cnx;
 
-
-/* If we really have to, use an insecure but exportable 512-bits key */
-# define RSA_EPHEMERAL_KEY_LEN 512
-
 /* The minimal number of bits we accept for a cipher */
 # define MINIMAL_CIPHER_KEY_LEN 40
 
